Flake8 CNS-OIST plugin
======================
Check usage STEPS subcellular simulator Python API.

Install
-------
Install with ip::

    $ pip install flake8-oist-steps

Requirements
------------
- Python 2.7, 3.5, 3.6, 3.7
- flake8

License
-------
GPL 2.0
